@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ts=4
 
 # Copyright 2017 Rémi Duraffort
@@ -17,6 +16,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
+import subprocess
+
 __all__ = [
     "__author__",
     "__author_email__",
@@ -28,8 +29,6 @@ __all__ = [
 
 
 def git_describe():
-    import subprocess
-
     try:
         # git describe?
         out = subprocess.check_output(["git", "describe"], stderr=subprocess.STDOUT)
@@ -42,5 +41,5 @@ __author__ = "Rémi Duraffort"
 __author_email__ = "remi.duraffort@linaro.org"
 __description__ = "LAVA XML-RPC command line interface"
 __license__ = "AGPLv3+"
-__url__ = "https://git.lavasoftware.org/lava/lavacli"
-__version__ = "1.5.2"
+__url__ = "https://gitlab.com/lava/lavacli"
+__version__ = "2.0.1"
