@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ts=4
 
 # Copyright 2017 Rémi Duraffort
@@ -19,31 +18,35 @@
 
 import argparse
 import os
+import socket
+import sys
+import xmlrpc.client
+from urllib.parse import urlparse
+
 import requests
 from requests.adapters import HTTPAdapter
 from requests.packages import urllib3
+from requests.packages.urllib3.exceptions import InsecureRequestWarning
 from requests.packages.urllib3.util.retry import Retry
-import socket
-from urllib.parse import urlparse
-import xmlrpc.client
 
 from .__about__ import __version__
-from .utils import parse_version, VERSION_LATEST, exc2str, safe_yaml
-
 from .commands import (
     aliases,
-    devices,
     device_types,
+    devices,
     events,
+    groups,
     identities,
     jobs,
     lab,
     results,
     system,
     tags,
+    users,
     utils,
     workers,
 )
+from .utils import VERSION_LATEST, exc2str, parse_version, safe_yaml
 
 
 class RequestsTransport(xmlrpc.client.Transport):
@@ -59,7 +62,7 @@ class RequestsTransport(xmlrpc.client.Transport):
             allowed_methods = "method_whitelist"  # pragma: no cover
         retry_strategy = Retry(
             total=3,
-            status_forcelist=[413, 429, 500, 503, 504],
+            status_forcelist=[413, 429, 500, 502, 503, 504],
             backoff_factor=1,
             **{allowed_methods: ["HEAD", "OPTIONS", "GET", "POST"]},
         )
@@ -76,8 +79,6 @@ class RequestsTransport(xmlrpc.client.Transport):
         self.timeout = timeout
         self.verify_ssl_cert = verify_ssl_cert
         if not verify_ssl_cert:
-            from requests.packages.urllib3.exceptions import InsecureRequestWarning
-
             requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
 
     def request(self, host, handler, request_body, verbose=False):
@@ -86,7 +87,7 @@ class RequestsTransport(xmlrpc.client.Transport):
             "Content-Type": "text/xml",
             "Accept-Encoding": "gzip",
         }
-        url = "%s://%s%s" % (self.scheme, host, handler)
+        url = f"{self.scheme}://{host}{handler}"
         try:
             response = None
             response = self.session.post(
@@ -123,7 +124,7 @@ def load_config(identity):
     config_filename = os.path.expanduser(os.path.join(config_dir, "lavacli.yaml"))
 
     try:
-        with open(config_filename, "r", encoding="utf-8") as f_conf:
+        with open(config_filename, encoding="utf-8") as f_conf:
             config = safe_yaml.load(f_conf.read())
         return config[identity]
     except (FileNotFoundError, KeyError, TypeError):
@@ -187,12 +188,14 @@ def main():
         "devices": devices,
         "device-types": device_types,
         "events": events,
+        "groups": groups,
         "identities": identities,
         "jobs": jobs,
         "lab": lab,
         "results": results,
         "system": system,
         "tags": tags,
+        "users": users,
         "utils": utils,
         "workers": workers,
     }
@@ -220,18 +223,21 @@ def main():
     version = VERSION_LATEST
     config = {}
 
-    # Skip when sub_command is "identities"
-    if remaining[0] not in ["identities", "utils"]:
+    lab_validate = False
+    if len(remaining) > 2 and remaining[0] == "lab" and remaining[1] == "validate":
+        lab_validate = True
+    # Skip when not needed.
+    if remaining[0] not in ["identities", "utils"] and not lab_validate:
         if uri is None:
             config = load_config(options.identity)
             if config.get("uri") is None:
-                print("Unknown identity '%s'" % options.identity)
+                print("Unknown identity '%s'" % options.identity, file=sys.stderr)
                 return 1
             username = config.get("username")
             token = config.get("token")
             if username is not None and token is not None:
                 p = urlparse(config["uri"])
-                uri = "%s://%s:%s@%s%s" % (p.scheme, username, token, p.netloc, p.path)
+                uri = f"{p.scheme}://{username}:{token}@{p.netloc}{p.path}"
             else:
                 uri = config["uri"]
 
@@ -248,7 +254,7 @@ def main():
             proxy = xmlrpc.client.ServerProxy(uri, allow_none=True, transport=transport)
             version = proxy.system.version()
         except (OSError, xmlrpc.client.Error) as exc:
-            print("Unable to connect: %s" % exc2str(exc))
+            print(f"Unable to connect: {exc2str(exc, options.uri)}", file=sys.stderr)
             return 1
 
         # Parse version
@@ -264,24 +270,27 @@ def main():
         # Run the command
         return commands[options.sub_command].handle(proxy, options, config)
     except (ConnectionError, socket.gaierror) as exc:
-        print("Unable to connect to '%s': %s" % (options.uri, str(exc)))
+        print(f"Unable to connect to '{options.uri}': {exc}", file=sys.stderr)
+        return 1
 
     except KeyboardInterrupt:
         pass
 
     except identities.ConfigurationError as exc:
-        print(exc)
+        print(exc, file=sys.stderr)
         return 1
     except xmlrpc.client.Error as exc:
-        msg = exc.errmsg if hasattr(exc, "errmsg") else str(exc)
         if "sub_sub_command" in options:
             print(
-                "Unable to call '%s.%s': %s"
-                % (options.sub_command, options.sub_sub_command, msg)
+                f"Unable to call '{options.sub_command}.{options.sub_sub_command}': {exc2str(exc, options.uri)}",
+                file=sys.stderr,
             )
         else:
-            print("Unable to call '%s': %s" % (options.sub_command, msg))
+            print(
+                f"Unable to call '{options.sub_command}': {exc2str(exc, options.uri)}",
+                file=sys.stderr,
+            )
     except BaseException as exc:
-        print("Unknown error: %s" % str(exc))
+        print("Unknown error: %s" % str(exc), file=sys.stderr)
 
     return 1
