@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ts=4
 
 # Copyright 2017 Rémi Duraffort
@@ -24,8 +23,8 @@ import json
 import pathlib
 import sys
 import time
-from urllib.parse import urlparse
 import xmlrpc.client
+from urllib.parse import urlparse
 
 from lavacli.utils import exc2str, log_yaml, safe_yaml
 
@@ -58,13 +57,12 @@ def configure_parser(parser, version):
     jobs_cancel = sub.add_parser("cancel", help="cancel a job")
     jobs_cancel.add_argument("job_id", nargs="+", help="job id")
 
-    if version >= (2018, 4):
-        # "config"
-        jobs_config = sub.add_parser("config", help="job configuration")
-        jobs_config.add_argument("job_id", help="job id")
-        jobs_config.add_argument(
-            "--dest", default=".", help="save files into this directory"
-        )
+    # "config"
+    jobs_config = sub.add_parser("config", help="job configuration")
+    jobs_config.add_argument("job_id", help="job id")
+    jobs_config.add_argument(
+        "--dest", default=".", help="save files into this directory"
+    )
 
     # "definition"
     jobs_definition = sub.add_parser("definition", help="job definition")
@@ -72,41 +70,39 @@ def configure_parser(parser, version):
 
     # "list"
     jobs_list = sub.add_parser("list", help="list jobs")
-    if version >= (2018, 4):
-        jobs_list.add_argument(
-            "--state",
-            type=str,
-            default=None,
-            choices=[
-                "SUBMITTED",
-                "SCHEDULING",
-                "SCHEDULED",
-                "RUNNING",
-                "CANCELING",
-                "FINISHED",
-            ],
-            help="filter jobs by state",
-        )
-        jobs_list.add_argument(
-            "--health",
-            type=str,
-            default=None,
-            choices=["UNKNOWN", "COMPLETE", "INCOMPLETE", "CANCELED"],
-            help="filter jobs by health",
-        )
-    if version >= (2018, 10):
-        jobs_list.add_argument(
-            "--since",
-            type=int,
-            default=0,
-            help="Filter by jobs which completed in the last N minutes.",
-        )
-        jobs_list.add_argument(
-            "--verbose",
-            dest="verbose",
-            action="store_true",
-            help="If verbose is True, add extra keys, including error_type.",
-        )
+    jobs_list.add_argument(
+        "--state",
+        type=str,
+        default=None,
+        choices=[
+            "SUBMITTED",
+            "SCHEDULING",
+            "SCHEDULED",
+            "RUNNING",
+            "CANCELING",
+            "FINISHED",
+        ],
+        help="filter jobs by state",
+    )
+    jobs_list.add_argument(
+        "--health",
+        type=str,
+        default=None,
+        choices=["UNKNOWN", "COMPLETE", "INCOMPLETE", "CANCELED"],
+        help="filter jobs by health",
+    )
+    jobs_list.add_argument(
+        "--since",
+        type=int,
+        default=0,
+        help="Filter by jobs which completed in the last N minutes.",
+    )
+    jobs_list.add_argument(
+        "--verbose",
+        dest="verbose",
+        action="store_true",
+        help="If verbose is True, add extra keys, including error_type.",
+    )
     jobs_list.add_argument(
         "--start", type=int, default=0, help="skip the N first jobs [default=0]"
     )
@@ -143,34 +139,31 @@ def configure_parser(parser, version):
     configure_log_options(jobs_logs)
 
     # "queue"
-    if version >= (2019, 1):
-        jobs_queue = sub.add_parser("queue", help="job queue")
-        jobs_queue.add_argument(
-            "device_types", nargs="*", help="filter by device-types"
-        )
-        out_format = jobs_queue.add_mutually_exclusive_group()
-        out_format.add_argument(
-            "--json",
-            dest="output_format",
-            default=None,
-            action="store_const",
-            const="json",
-            help="print as json",
-        )
-        out_format.add_argument(
-            "--yaml",
-            dest="output_format",
-            action="store_const",
-            const="yaml",
-            default=None,
-            help="print as yaml",
-        )
-        jobs_queue.add_argument(
-            "--start", type=int, default=0, help="skip the N first jobs [default=0]"
-        )
-        jobs_queue.add_argument(
-            "--limit", type=int, default=25, help="limit to N jobs [default=25]"
-        )
+    jobs_queue = sub.add_parser("queue", help="job queue")
+    jobs_queue.add_argument("device_types", nargs="*", help="filter by device-types")
+    out_format = jobs_queue.add_mutually_exclusive_group()
+    out_format.add_argument(
+        "--json",
+        dest="output_format",
+        default=None,
+        action="store_const",
+        const="json",
+        help="print as json",
+    )
+    out_format.add_argument(
+        "--yaml",
+        dest="output_format",
+        action="store_const",
+        const="yaml",
+        default=None,
+        help="print as yaml",
+    )
+    jobs_queue.add_argument(
+        "--start", type=int, default=0, help="skip the N first jobs [default=0]"
+    )
+    jobs_queue.add_argument(
+        "--limit", type=int, default=25, help="limit to N jobs [default=25]"
+    )
 
     # "resubmit"
     jobs_resubmit = sub.add_parser("resubmit", help="resubmit a job")
@@ -274,22 +267,21 @@ def configure_parser(parser, version):
             "--strict", action="store_true", default=False, help="check in strict mode"
         )
 
-    if version >= (2018, 1):
-        # "wait"
-        jobs_wait = sub.add_parser("wait", help="wait for the job to finish")
-        jobs_wait.add_argument("job_id", help="job id")
-        jobs_wait.add_argument(
-            "--polling",
-            default=5,
-            type=int,
-            help="polling interval in seconds [default=5s]",
-        )
-        jobs_wait.add_argument(
-            "--timeout",
-            default=0,
-            type=int,
-            help="Maximum time to wait in seconds, 0 to disable [default=0s]",
-        )
+    # "wait"
+    jobs_wait = sub.add_parser("wait", help="wait for the job to finish")
+    jobs_wait.add_argument("job_id", help="job id")
+    jobs_wait.add_argument(
+        "--polling",
+        default=5,
+        type=int,
+        help="polling interval in seconds [default=5s]",
+    )
+    jobs_wait.add_argument(
+        "--timeout",
+        default=0,
+        type=int,
+        help="Maximum time to wait in seconds, 0 to disable [default=0s]",
+    )
 
 
 def help_string():
@@ -297,12 +289,17 @@ def help_string():
 
 
 def handle_cancel(proxy, options, _):
+    ret = 0
     for job_id in options.job_id:
         try:
             proxy.scheduler.jobs.cancel(job_id)
         except xmlrpc.client.Error as exc:
-            print("Unable to cancel job %s: %s" % (job_id, exc2str(exc)))
-    return 0
+            print(
+                f"Unable to cancel job {job_id}: {exc2str(exc, options.uri)}",
+                file=sys.stderr,
+            )
+            ret = 1
+    return ret
 
 
 def handle_config(proxy, options, _):
@@ -338,32 +335,23 @@ def handle_definition(proxy, options, _):
 
 
 def handle_list(proxy, options, config):
-    if config["version"] >= (2018, 10):
-        jobs = proxy.scheduler.jobs.list(
-            options.state,
-            options.health,
-            options.start,
-            options.limit,
-            options.since,
-            options.verbose,
-        )
-    elif config["version"] >= (2018, 4):
-        jobs = proxy.scheduler.jobs.list(
-            options.state, options.health, options.start, options.limit
-        )
-    else:
-        jobs = proxy.scheduler.jobs.list(options.start, options.limit)
+    jobs = proxy.scheduler.jobs.list(
+        options.state,
+        options.health,
+        options.start,
+        options.limit,
+        options.since,
+        options.verbose,
+    )
 
     if options.output_format == "json":
         print(json.dumps(jobs))
     elif options.output_format == "yaml":
         safe_yaml.dump(jobs, sys.stdout)
     else:
-        print(
-            "Jobs (from %s to %s):" % (1 + options.start, options.start + options.limit)
-        )
+        print(f"Jobs (from {1 + options.start} to {options.start + options.limit}):")
         for job in jobs:
-            if config["version"] >= (2018, 10) and options.verbose:
+            if options.verbose:
                 if job["error_type"]:
                     print(
                         "* %s: %s,%s [%s] (%s) - %s %s <%s> <%s> %s: %s"
@@ -397,7 +385,7 @@ def handle_list(proxy, options, config):
                         )
                     )
 
-            elif config["version"] >= (2018, 1):
+            else:
                 print(
                     "* %s: %s,%s [%s] (%s) - %s"
                     % (
@@ -409,17 +397,6 @@ def handle_list(proxy, options, config):
                         job["device_type"],
                     )
                 )
-            else:
-                print(
-                    "* %s: %s [%s] (%s) - %s"
-                    % (
-                        job["id"],
-                        job["status"],
-                        job["submitter"],
-                        job["description"],
-                        job["device_type"],
-                    )
-                )
     return 0
 
 
@@ -495,16 +472,8 @@ def print_logs(logs, raw, filters):
 
 
 def _download_logs(proxy, version, job_id, start, end):
-    if version >= (2018, 6):
-        (finished, data) = proxy.scheduler.jobs.logs(job_id, start, end)
-        logs = safe_yaml.load(str(data))
-    else:
-        (finished, data) = proxy.scheduler.jobs.logs(job_id, start)
-        logs = safe_yaml.load(str(data))
-        if end is not None and len(logs) >= end - start:
-            if end < start:
-                end = start
-            logs = logs[: end - start]
+    (finished, data) = proxy.scheduler.jobs.logs(job_id, start, end)
+    logs = safe_yaml.load(str(data))
     return (finished, logs)
 
 
@@ -561,18 +530,10 @@ def handle_queue(proxy, options, config):
     elif options.output_format == "yaml":
         safe_yaml.dump(data, sys.stdout)
     else:
-        print(
-            "Jobs (from %s to %s):" % (1 + options.start, options.start + options.limit)
-        )
+        print(f"Jobs (from {1+options.start} to {options.start + options.limit}):")
         for job in data:
             print(
-                "* %s: %s (%s) - %s"
-                % (
-                    job["id"],
-                    job["submitter"],
-                    job["description"] if job["description"] else "",
-                    job["requested_device_type"],
-                )
+                f"* {job['id']}: {job['submitter']} ({job['description'] or ''}) - {job['requested_device_type']}"
             )
     return 0
 
@@ -585,7 +546,7 @@ def handle_resubmit(proxy, options, config):
         if options.print_url:
             parsed = urlparse(options.uri)
             host = parsed.netloc.split("@")[-1]
-            prefix = "%s://%s/scheduler/job/" % (parsed.scheme, host)
+            prefix = f"{parsed.scheme}://{host}/scheduler/job/"
 
         if isinstance(job_id, list):
             for job in job_id:
@@ -674,14 +635,14 @@ def handle_show(proxy, options, config):
     job = proxy.scheduler.jobs.show(options.job_id)
 
     if options.output_format == "json":
-        job["submit_time"] = job["submit_time"].value if job["submit_time"] else None
-        job["start_time"] = job["start_time"].value if job["start_time"] else None
-        job["end_time"] = job["end_time"].value if job["end_time"] else None
+        job["submit_time"] = job["submit_time"].value or None
+        job["start_time"] = job["start_time"].value or None
+        job["end_time"] = job["end_time"].value or None
         print(json.dumps(job))
     elif options.output_format == "yaml":
-        job["submit_time"] = job["submit_time"].value if job["submit_time"] else None
-        job["start_time"] = job["start_time"].value if job["start_time"] else None
-        job["end_time"] = job["end_time"].value if job["end_time"] else None
+        job["submit_time"] = job["submit_time"].value or None
+        job["start_time"] = job["start_time"].value or None
+        job["end_time"] = job["end_time"].value or None
         safe_yaml.dump(job, sys.stdout)
     else:
         print("id          : %s" % job["id"])
@@ -690,11 +651,8 @@ def handle_show(proxy, options, config):
         print("device-type : %s" % job["device_type"])
         print("device      : %s" % job["device"])
         print("health-check: %s" % job["health_check"])
-        if config["version"] >= (2018, 1):
-            print("state       : %s" % job["state"])
-            print("Health      : %s" % job["health"])
-        else:
-            print("status      : %s" % job["status"])
+        print("state       : %s" % job["state"])
+        print("Health      : %s" % job["health"])
         if job.get("failure_comment"):
             print("failure     : %s" % job["failure_comment"])
         print("pipeline    : %s" % job["pipeline"])
@@ -711,7 +669,7 @@ def handle_submit(proxy, options, config):
     if options.print_url:
         parsed = urlparse(options.uri)
         host = parsed.netloc.split("@")[-1]
-        prefix = "%s://%s/scheduler/job/" % (parsed.scheme, host)
+        prefix = f"{parsed.scheme}://{host}/scheduler/job/"
 
     for definition in options.definition:
         try:
@@ -723,7 +681,11 @@ def handle_submit(proxy, options, config):
                 else:
                     print(prefix + str(job_id))
         except xmlrpc.client.Error as exc:
-            print("Unable to submit %s: %s" % (definition.name, exc2str(exc)))
+            print(
+                f"Unable to submit {definition.name}: {exc2str(exc, options.uri)}",
+                file=sys.stderr,
+            )
+            return 1
 
     if not options.no_follow:
         follow_logs(job_id, proxy, options, config)
