@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ts=4
 
 # Copyright 2017 Rémi Duraffort
@@ -17,15 +16,16 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
-import pytest
 import xmlrpc.client
 
+import pytest
+
 from lavacli.utils import safe_yaml
 
 
-class RecordingProxyFactory(object):
-    def __new__(self, proxy_data):
-        class RecordingProxy(object):
+class RecordingProxyFactory:
+    def __new__(cls, proxy_data):
+        class RecordingProxy:
             data = proxy_data
 
             def __init__(self, uri, allow_none, transport):
@@ -47,8 +47,8 @@ class RecordingProxyFactory(object):
 
 
 @pytest.fixture
-def setup(monkeypatch, tmpdir):
-    monkeypatch.setenv("XDG_CONFIG_HOME", str(tmpdir))
-    with (tmpdir / "lavacli.yaml").open("w") as f_conf:
+def setup(monkeypatch, tmp_path):
+    monkeypatch.setenv("XDG_CONFIG_HOME", str(tmp_path))
+    with (tmp_path / "lavacli.yaml").open("w") as f_conf:
         safe_yaml.dump({"default": {"uri": "https://lava.example.com/RPC2"}}, f_conf)
     monkeypatch.setattr(xmlrpc.client, "ServerProxy", RecordingProxyFactory(None))
