@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ts=4
 
 # Copyright 2018 Rémi Duraffort
@@ -27,7 +26,7 @@ from lavacli.utils import safe_yaml
 
 
 def test_jobs_cancel(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "cancel", "1234"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -41,10 +40,10 @@ def test_jobs_cancel(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == ""  # nosec
 
 
-def test_jobs_config(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
+def test_jobs_config(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
     monkeypatch.setattr(
-        sys, "argv", ["lavacli", "jobs", "config", "1234", "--dest", str(tmpdir)]
+        sys, "argv", ["lavacli", "jobs", "config", "1234", "--dest", str(tmp_path)]
     )
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -60,20 +59,20 @@ def test_jobs_config(setup, monkeypatch, capsys, tmpdir):
     )
     assert main() == 0  # nosec
     assert capsys.readouterr()[0] == ""  # nosec
-    with (tmpdir / "definition.yaml").open() as f_in:
+    with (tmp_path / "definition.yaml").open() as f_in:
         assert f_in.read() == "definition"  # nosec
-    with (tmpdir / "device.yaml").open() as f_in:
+    with (tmp_path / "device.yaml").open() as f_in:
         assert f_in.read() == "device"  # nosec
-    with (tmpdir / "dispatcher.yaml").open() as f_in:
+    with (tmp_path / "dispatcher.yaml").open() as f_in:
         assert f_in.read() == "dispatcher"  # nosec
-    with (tmpdir / "env.yaml").open() as f_in:
+    with (tmp_path / "env.yaml").open() as f_in:
         assert f_in.read() == "env"  # nosec
-    with (tmpdir / "env.dut.yaml").open() as f_in:
+    with (tmp_path / "env.dut.yaml").open() as f_in:
         assert f_in.read() == "env.dut"  # nosec
 
 
 def test_jobs_definition(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "definition", "1234"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -91,181 +90,8 @@ def test_jobs_definition(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == "definition\n"  # nosec
 
 
-def test_jobs_list_before_2018_1(setup, monkeypatch, capsys):
-    version = "2017.12"
-    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "list"])
-    monkeypatch.setattr(
-        xmlrpc.client.ServerProxy,
-        "data",
-        [
-            {"request": "system.version", "args": (), "ret": version},
-            {
-                "request": "scheduler.jobs.list",
-                "args": (0, 25),
-                "ret": [
-                    {
-                        "id": "16",
-                        "description": "hello",
-                        "device_type": "bbb",
-                        "status": "Complete",
-                        "submitter": "lava",
-                    },
-                    {
-                        "id": "15",
-                        "description": "world",
-                        "device_type": "qemu",
-                        "status": "Incomplete",
-                        "submitter": "lab",
-                    },
-                    {
-                        "id": "14",
-                        "description": "health",
-                        "device_type": "docker",
-                        "status": "Canceled",
-                        "submitter": "lava-health",
-                    },
-                    {
-                        "id": "12",
-                        "description": "something",
-                        "device_type": "",
-                        "status": "Running",
-                        "submitter": "admin",
-                    },
-                ],
-            },
-        ],
-    )
-    assert main() == 0  # nosec
-    assert (  # nosec
-        capsys.readouterr()[0]
-        == """Jobs (from 1 to 25):
-* 16: Complete [lava] (hello) - bbb
-* 15: Incomplete [lab] (world) - qemu
-* 14: Canceled [lava-health] (health) - docker
-* 12: Running [admin] (something) - \n"""
-    )
-
-
-def test_jobs_list_before_2018_4(setup, monkeypatch, capsys):
-    version = "2018.2"
-    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "list"])
-    monkeypatch.setattr(
-        xmlrpc.client.ServerProxy,
-        "data",
-        [
-            {"request": "system.version", "args": (), "ret": version},
-            {
-                "request": "scheduler.jobs.list",
-                "args": (0, 25),
-                "ret": [
-                    {
-                        "id": "16",
-                        "description": "hello",
-                        "device_type": "bbb",
-                        "health": "Complete",
-                        "state": "Runished",
-                        "submitter": "lava",
-                    },
-                    {
-                        "id": "15",
-                        "description": "world",
-                        "device_type": "qemu",
-                        "health": "Incomplete",
-                        "state": "Finished",
-                        "submitter": "lab",
-                    },
-                    {
-                        "id": "14",
-                        "description": "health",
-                        "device_type": "docker",
-                        "health": "Canceled",
-                        "state": "Finished",
-                        "submitter": "lava-health",
-                    },
-                    {
-                        "id": "12",
-                        "description": "something",
-                        "device_type": "",
-                        "health": "Unknown",
-                        "state": "Running",
-                        "submitter": "admin",
-                    },
-                ],
-            },
-        ],
-    )
-    assert main() == 0  # nosec
-    assert (  # nosec
-        capsys.readouterr()[0]
-        == """Jobs (from 1 to 25):
-* 16: Runished,Complete [lava] (hello) - bbb
-* 15: Finished,Incomplete [lab] (world) - qemu
-* 14: Finished,Canceled [lava-health] (health) - docker
-* 12: Running,Unknown [admin] (something) - \n"""
-    )
-
-
-def test_jobs_list_before_2018_10(setup, monkeypatch, capsys):
-    version = "2018.4"
-    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "list"])
-    monkeypatch.setattr(
-        xmlrpc.client.ServerProxy,
-        "data",
-        [
-            {"request": "system.version", "args": (), "ret": version},
-            {
-                "request": "scheduler.jobs.list",
-                "args": (None, None, 0, 25),
-                "ret": [
-                    {
-                        "id": "16",
-                        "description": "hello",
-                        "device_type": "bbb",
-                        "health": "Complete",
-                        "state": "Rinished",
-                        "submitter": "lava",
-                    },
-                    {
-                        "id": "15",
-                        "description": "world",
-                        "device_type": "qemu",
-                        "health": "Incomplete",
-                        "state": "Finished",
-                        "submitter": "lab",
-                    },
-                    {
-                        "id": "14",
-                        "description": "health",
-                        "device_type": "docker",
-                        "health": "Canceled",
-                        "state": "Finished",
-                        "submitter": "lava-health",
-                    },
-                    {
-                        "id": "12",
-                        "description": "something",
-                        "device_type": "",
-                        "health": "Unknown",
-                        "state": "Running",
-                        "submitter": "admin",
-                    },
-                ],
-            },
-        ],
-    )
-    assert main() == 0  # nosec
-    assert (  # nosec
-        capsys.readouterr()[0]
-        == """Jobs (from 1 to 25):
-* 16: Rinished,Complete [lava] (hello) - bbb
-* 15: Finished,Incomplete [lab] (world) - qemu
-* 14: Finished,Canceled [lava-health] (health) - docker
-* 12: Running,Unknown [admin] (something) - \n"""
-    )
-
-
 def test_jobs_list(setup, monkeypatch, capsys):
-    version = "2018.10"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "list"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -306,7 +132,7 @@ def test_jobs_list(setup, monkeypatch, capsys):
 
 
 def test_jobs_list_since_verbose(setup, monkeypatch, capsys):
-    version = "2018.10"
+    version = "2019.1"
     monkeypatch.setattr(
         sys, "argv", ["lavacli", "jobs", "list", "--verbose", "--since", "5"]
     )
@@ -359,7 +185,7 @@ def test_jobs_list_since_verbose(setup, monkeypatch, capsys):
 
 
 def test_jobs_list_json(setup, monkeypatch, capsys):
-    version = "2018.10"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "list", "--json"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -444,7 +270,7 @@ def test_jobs_list_json(setup, monkeypatch, capsys):
 
 
 def test_jobs_list_yaml(setup, monkeypatch, capsys):
-    version = "2018.10"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "list", "--yaml"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -507,7 +333,7 @@ def test_jobs_list_yaml(setup, monkeypatch, capsys):
 
 
 def test_jobs_list_filtering(setup, monkeypatch, capsys):
-    version = "2018.10"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "list", "--state", "RUNNING"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -526,7 +352,7 @@ def test_jobs_list_filtering(setup, monkeypatch, capsys):
 
 
 def test_jobs_list_filtering2(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     monkeypatch.setattr(
         sys,
         "argv",
@@ -549,7 +375,7 @@ def test_jobs_list_filtering2(setup, monkeypatch, capsys):
             {"request": "system.version", "args": (), "ret": version},
             {
                 "request": "scheduler.jobs.list",
-                "args": (None, "CANCELED", 45, 56),
+                "args": (None, "CANCELED", 45, 56, 0, False),
                 "ret": [],
             },
         ],
@@ -560,7 +386,7 @@ def test_jobs_list_filtering2(setup, monkeypatch, capsys):
 
 # TODO: test with 2018.6 and also --start/--end
 def test_jobs_logs(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
@@ -575,15 +401,15 @@ def test_jobs_logs(setup, monkeypatch, capsys):
             {"request": "system.version", "args": (), "ret": version},
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 0),
+                "args": ("1234", 0, None),
                 "ret": (
                     False,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 1),
+                "args": ("1234", 1, None),
                 "ret": (
                     True,
                     """- {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
@@ -617,7 +443,7 @@ def test_jobs_logs(setup, monkeypatch, capsys):
     lines = capsys.readouterr()[0].split("\n")
     assert (  # nosec
         lines[0]
-        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1"
+        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2019.1-1"
     )
     assert lines[1][:20] == "2018-04-23T12:07:02 "  # nosec
     assert safe_yaml.load(lines[1][20:]) == {  # nosec
@@ -632,7 +458,7 @@ def test_jobs_logs(setup, monkeypatch, capsys):
 
 
 def test_jobs_logs_failure_comment_and_polling(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
@@ -649,15 +475,15 @@ def test_jobs_logs_failure_comment_and_polling(setup, monkeypatch, capsys):
             {"request": "system.version", "args": (), "ret": version},
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 0),
+                "args": ("1234", 0, None),
                 "ret": (
                     False,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 1),
+                "args": ("1234", 1, None),
                 "ret": (
                     True,
                     """- {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
@@ -691,7 +517,7 @@ def test_jobs_logs_failure_comment_and_polling(setup, monkeypatch, capsys):
     lines = capsys.readouterr()[0].split("\n")
     assert (  # nosec
         lines[0]
-        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1"
+        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2019.1-1"
     )
     assert lines[1][:20] == "2018-04-23T12:07:02 "  # nosec
     assert safe_yaml.load(lines[1][20:]) == {  # nosec
@@ -709,7 +535,7 @@ def test_jobs_logs_failure_comment_and_polling(setup, monkeypatch, capsys):
 
 
 def test_jobs_logs_filtering(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
@@ -726,15 +552,15 @@ def test_jobs_logs_filtering(setup, monkeypatch, capsys):
             {"request": "system.version", "args": (), "ret": version},
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 0),
+                "args": ("1234", 0, None),
                 "ret": (
                     False,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 1),
+                "args": ("1234", 1, None),
                 "ret": (
                     True,
                     """- {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
@@ -767,14 +593,14 @@ def test_jobs_logs_filtering(setup, monkeypatch, capsys):
     assert main() == 0  # nosec
     assert (  # nosec
         capsys.readouterr()[0]
-        == """2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1
+        == """2018-04-23T12:07:02 lava-dispatcher, installed at version: 2019.1-1
 2018-04-23T12:07:02 start: 1.1 download-retry (timeout 00:02:00) [common]
 """
     )
 
 
 def test_jobs_logs_raw(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
@@ -789,15 +615,15 @@ def test_jobs_logs_raw(setup, monkeypatch, capsys):
             {"request": "system.version", "args": (), "ret": version},
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 0),
+                "args": ("1234", 0, None),
                 "ret": (
                     False,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 1),
+                "args": ("1234", 1, None),
                 "ret": (
                     True,
                     """- {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
@@ -830,7 +656,7 @@ def test_jobs_logs_raw(setup, monkeypatch, capsys):
     assert main() == 0  # nosec
     assert (  # nosec
         capsys.readouterr()[0]
-        == """- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}
+        == """- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}
 - {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
 - {"dt": "2018-04-23T12:07:02.573414", "lvl": "debug", "msg": "start: 1.1 download-retry (timeout 00:02:00) [common]"}
 """
@@ -838,7 +664,7 @@ def test_jobs_logs_raw(setup, monkeypatch, capsys):
 
 
 def test_jobs_logs_raw_filter(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
@@ -857,15 +683,15 @@ def test_jobs_logs_raw_filter(setup, monkeypatch, capsys):
             {"request": "system.version", "args": (), "ret": version},
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 0),
+                "args": ("1234", 0, None),
                 "ret": (
                     False,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 1),
+                "args": ("1234", 1, None),
                 "ret": (
                     True,
                     """- {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
@@ -1073,7 +899,7 @@ def test_jobs_queue_filtering(setup, monkeypatch, capsys):
 
 
 def test_jobs_resubmit(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "resubmit", "1234"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -1088,7 +914,7 @@ def test_jobs_resubmit(setup, monkeypatch, capsys):
 
 
 def test_jobs_resubmit_url(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     monkeypatch.setattr(
         sys,
         "argv",
@@ -1117,7 +943,7 @@ def test_jobs_resubmit_url(setup, monkeypatch, capsys):
 
 
 def test_jobs_resubmit_mutlinode(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "resubmit", "1234"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -1136,7 +962,7 @@ def test_jobs_resubmit_mutlinode(setup, monkeypatch, capsys):
 
 
 def test_jobs_resubmit_mutlinode_url(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     monkeypatch.setattr(
         sys,
         "argv",
@@ -1170,7 +996,7 @@ def test_jobs_resubmit_mutlinode_url(setup, monkeypatch, capsys):
 
 
 def test_jobs_resubmit_follow(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
@@ -1190,15 +1016,15 @@ def test_jobs_resubmit_follow(setup, monkeypatch, capsys):
             {"request": "scheduler.jobs.resubmit", "args": ("1234",), "ret": 1234},
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 0),
+                "args": ("1234", 0, None),
                 "ret": (
                     False,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("1234", 1),
+                "args": ("1234", 1, None),
                 "ret": (
                     True,
                     """- {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
@@ -1233,7 +1059,7 @@ def test_jobs_resubmit_follow(setup, monkeypatch, capsys):
     assert lines[0].endswith("[lavacli] Job 1234 submitted")  # nosec
     assert (  # nosec
         lines[1]
-        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1"
+        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2019.1-1"
     )
     assert (  # nosec
         lines[2]
@@ -1241,18 +1067,18 @@ def test_jobs_resubmit_follow(setup, monkeypatch, capsys):
     )
 
 
-def test_jobs_run(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
+def test_jobs_run(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
         assert duration == 5  # nosec
 
-    with (tmpdir / "job.yaml").open("w") as f_out:
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition")
     monkeypatch.setattr(time, "sleep", sleep)
     monkeypatch.setattr(
-        sys, "argv", ["lavacli", "jobs", "run", str(tmpdir / "job.yaml")]
+        sys, "argv", ["lavacli", "jobs", "run", str(tmp_path / "job.yaml")]
     )
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -1266,15 +1092,15 @@ def test_jobs_run(setup, monkeypatch, capsys, tmpdir):
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("4567", 0),
+                "args": ("4567", 0, None),
                 "ret": (
                     False,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("4567", 1),
+                "args": ("4567", 1, None),
                 "ret": (
                     True,
                     """- {"dt": "2018-04-23T12:07:02.572789", "lvl": "results", "msg": {"case": "validate", "definition": "lava", "result": "pass"}}
@@ -1309,7 +1135,7 @@ def test_jobs_run(setup, monkeypatch, capsys, tmpdir):
     assert lines[0].endswith("[lavacli] Job 4567 submitted")  # nosec
     assert (  # nosec
         lines[1]
-        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1"
+        == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2019.1-1"
     )
     assert lines[2][:20] == "2018-04-23T12:07:02 "  # nosec
     assert safe_yaml.load(lines[2][20:]) == {  # nosec
@@ -1323,59 +1149,8 @@ def test_jobs_run(setup, monkeypatch, capsys, tmpdir):
     )
 
 
-def test_jobs_show_before_2018_1(setup, monkeypatch, capsys):
-    version = "2017.12"
-    now = xmlrpc.client.DateTime("20180128T01:01:01")
-    monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "show", "789"])
-    monkeypatch.setattr(
-        xmlrpc.client.ServerProxy,
-        "data",
-        [
-            {"request": "system.version", "args": (), "ret": version},
-            {
-                "request": "scheduler.jobs.show",
-                "args": ("789",),
-                "ret": {
-                    "id": "789",
-                    "description": "desc",
-                    "device": "qemu01",
-                    "device_type": "qemu",
-                    "health_check": False,
-                    "pipeline": True,
-                    "status": "Complete",
-                    "submitter": "lava-admin",
-                    "submit_time": now,
-                    "start_time": now,
-                    "end_time": now,
-                    "tags": [],
-                    "visibility": "Publicly visible",
-                    "failure_comment": None,
-                },
-            },
-        ],
-    )
-    assert main() == 0  # nosec
-    assert (  # nosec
-        capsys.readouterr()[0]
-        == """id          : 789
-description : desc
-submitter   : lava-admin
-device-type : qemu
-device      : qemu01
-health-check: False
-status      : Complete
-pipeline    : True
-tags        : []
-visibility  : Publicly visible
-submit time : 20180128T01:01:01
-start time  : 20180128T01:01:01
-end time    : 20180128T01:01:01
-"""
-    )
-
-
 def test_jobs_show(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "show", "789"])
     monkeypatch.setattr(
@@ -1428,7 +1203,7 @@ end time    : 20180128T01:01:01
 
 
 def test_jobs_show_failure_comment(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "show", "789"])
     monkeypatch.setattr(
@@ -1482,7 +1257,7 @@ end time    : 20180128T01:01:01
 
 
 def test_jobs_show_json(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "show", "789", "--json"])
     monkeypatch.setattr(
@@ -1534,7 +1309,7 @@ def test_jobs_show_json(setup, monkeypatch, capsys):
 
 
 def test_jobs_show_yaml(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
     monkeypatch.setattr(sys, "argv", ["lavacli", "jobs", "show", "789", "--yaml"])
     monkeypatch.setattr(
@@ -1587,12 +1362,12 @@ visibility: Publicly visible
     )
 
 
-def test_jobs_submit(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job.yaml").open("w") as f_out:
+def test_jobs_submit(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
     monkeypatch.setattr(
-        sys, "argv", ["lavacli", "jobs", "submit", str(tmpdir / "job.yaml")]
+        sys, "argv", ["lavacli", "jobs", "submit", str(tmp_path / "job.yaml")]
     )
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -1610,9 +1385,9 @@ def test_jobs_submit(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "5689\n"  # nosec
 
 
-def test_jobs_submit_url(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job.yaml").open("w") as f_out:
+def test_jobs_submit_url(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
     monkeypatch.setattr(
         sys,
@@ -1623,7 +1398,7 @@ def test_jobs_submit_url(setup, monkeypatch, capsys, tmpdir):
             "https://localhost:8000/RPC2",
             "jobs",
             "submit",
-            str(tmpdir / "job.yaml"),
+            str(tmp_path / "job.yaml"),
             "--url",
         ],
     )
@@ -1645,12 +1420,12 @@ def test_jobs_submit_url(setup, monkeypatch, capsys, tmpdir):
     )
 
 
-def test_jobs_submit_url_identity_default(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job.yaml").open("w") as f_out:
+def test_jobs_submit_url_identity_default(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
     monkeypatch.setattr(
-        sys, "argv", ["lavacli", "jobs", "submit", str(tmpdir / "job.yaml"), "--url"]
+        sys, "argv", ["lavacli", "jobs", "submit", str(tmp_path / "job.yaml"), "--url"]
     )
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -1670,11 +1445,11 @@ def test_jobs_submit_url_identity_default(setup, monkeypatch, capsys, tmpdir):
     )
 
 
-def test_jobs_submit_url_identity_admin(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job.yaml").open("w") as f_out:
+def test_jobs_submit_url_identity_admin(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
-    with (tmpdir / "lavacli.yaml").open("w") as f_conf:
+    with (tmp_path / "lavacli.yaml").open("w") as f_conf:
         safe_yaml.dump(
             {
                 "default": {"uri": "https://lava.example.com/RPC2"},
@@ -1685,7 +1460,15 @@ def test_jobs_submit_url_identity_admin(setup, monkeypatch, capsys, tmpdir):
     monkeypatch.setattr(
         sys,
         "argv",
-        ["lavacli", "-i", "admin", "jobs", "submit", str(tmpdir / "job.yaml"), "--url"],
+        [
+            "lavacli",
+            "-i",
+            "admin",
+            "jobs",
+            "submit",
+            str(tmp_path / "job.yaml"),
+            "--url",
+        ],
     )
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -1705,13 +1488,13 @@ def test_jobs_submit_url_identity_admin(setup, monkeypatch, capsys, tmpdir):
     )
 
 
-def test_jobs_submit_multiple(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job1.yaml").open("w") as f_out:
+def test_jobs_submit_multiple(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job1.yaml").open("w") as f_out:
         f_out.write("first job definition as yaml")
-    with (tmpdir / "job2.yaml").open("w") as f_out:
+    with (tmp_path / "job2.yaml").open("w") as f_out:
         f_out.write("second job definition as yaml")
-    with (tmpdir / "job3.yaml").open("w") as f_out:
+    with (tmp_path / "job3.yaml").open("w") as f_out:
         f_out.write("third job definition as yaml")
     monkeypatch.setattr(
         sys,
@@ -1720,9 +1503,9 @@ def test_jobs_submit_multiple(setup, monkeypatch, capsys, tmpdir):
             "lavacli",
             "jobs",
             "submit",
-            str(tmpdir / "job1.yaml"),
-            str(tmpdir / "job2.yaml"),
-            str(tmpdir / "job3.yaml"),
+            str(tmp_path / "job1.yaml"),
+            str(tmp_path / "job2.yaml"),
+            str(tmp_path / "job3.yaml"),
         ],
     )
     monkeypatch.setattr(
@@ -1751,12 +1534,12 @@ def test_jobs_submit_multiple(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "5689\n5690\n5691\n5692\n"  # nosec
 
 
-def test_jobs_submit_multinode(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job.yaml").open("w") as f_out:
+def test_jobs_submit_multinode(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
     monkeypatch.setattr(
-        sys, "argv", ["lavacli", "jobs", "submit", str(tmpdir / "job.yaml")]
+        sys, "argv", ["lavacli", "jobs", "submit", str(tmp_path / "job.yaml")]
     )
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -1774,9 +1557,9 @@ def test_jobs_submit_multinode(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "5689\n5698\n"  # nosec
 
 
-def test_jobs_submit_multinode_url(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job.yaml").open("w") as f_out:
+def test_jobs_submit_multinode_url(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
     monkeypatch.setattr(
         sys,
@@ -1787,7 +1570,7 @@ def test_jobs_submit_multinode_url(setup, monkeypatch, capsys, tmpdir):
             "https://localhost:8000/RPC2",
             "jobs",
             "submit",
-            str(tmpdir / "job.yaml"),
+            str(tmp_path / "job.yaml"),
             "--url",
         ],
     )
@@ -1811,7 +1594,7 @@ def test_jobs_submit_multinode_url(setup, monkeypatch, capsys, tmpdir):
 
 
 def test_jobs_wait(setup, monkeypatch, capsys):
-    version = "2018.4"
+    version = "2019.1"
     now = xmlrpc.client.DateTime("20180128T01:01:01")
 
     def sleep(duration):
@@ -1915,12 +1698,14 @@ def test_jobs_wait(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == "Submitted\nRunning.\n"  # nosec
 
 
-def test_jobs_submit_follow(setup, monkeypatch, capsys, tmpdir):
-    version = "2018.4"
-    with (tmpdir / "job.yaml").open("w") as f_out:
+def test_jobs_submit_follow(setup, monkeypatch, capsys, tmp_path):
+    version = "2019.1"
+    with (tmp_path / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
     monkeypatch.setattr(
-        sys, "argv", ["lavacli", "jobs", "submit", "--follow", str(tmpdir / "job.yaml")]
+        sys,
+        "argv",
+        ["lavacli", "jobs", "submit", "--follow", str(tmp_path / "job.yaml")],
     )
     now = xmlrpc.client.DateTime("20180128T01:01:01")
     monkeypatch.setattr(
@@ -1935,10 +1720,10 @@ def test_jobs_submit_follow(setup, monkeypatch, capsys, tmpdir):
             },
             {
                 "request": "scheduler.jobs.logs",
-                "args": ("5689", 0),
+                "args": ("5689", 0, None),
                 "ret": (
                     True,
-                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2019.1-1"}',
                 ),
             },
             {
@@ -1965,4 +1750,4 @@ def test_jobs_submit_follow(setup, monkeypatch, capsys, tmpdir):
         ],
     )
     assert main() == 0  # nosec
-    assert "lava-dispatcher, installed at version: 2018.4" in capsys.readouterr()[0]
+    assert "lava-dispatcher, installed at version: 2019.1" in capsys.readouterr()[0]
